'
'C source for GNU CHESS
'
'Revision: 1990-09-30
'
'Modified by Daryl Baker for use in MS WINDOWS environment
' Converted to BCX by Garvan O'Keeffe April 2005
'
'Based on Ideas and code segments of Charles Petzold from artices in
'MicroSoft Systems Journal.
'
'
'This file is part of CHESS.
'
'CHESS is distributed in the hope that it will be useful, but WITHOUT ANY
'WARRANTY.  No author or distributor accepts responsibility to anyone for
'the consequences of using it or for whether it serves any particular
'purpose or works at all, unless he says so in writing.  Refer to the CHESS
'General Public License for full details.
'
'Everyone is granted permission to copy, modify and redistribute CHESS, but
'only under the conditions described in the CHESS General Public License.
'A copy of this license is supposed to have been given to you along with
'CHESS so you can know your rights and responsibilities.  It should be in a
'file named COPYING.  Among other things, the copyright notice and this
'notice must be preserved on all copies.
'

SUB QueryBoardSize (pptl AS POINT PTR)
  pptl->x = 2 *BRD_HORZMARGIN + 8 *BRD_HORZFRONT
  pptl->y = BRD_BACKMARGIN + 8 *BRD_VERT + 2 *BRD_FRONTMARGIN + 2 *BRD_EDGE
END SUB

SUB QuerySqSize (pptl AS POINT PTR)
  pptl->x = BRD_HORZFRONT
  pptl->y = BRD_VERT
END SUB

SUB QuerySqOrigin (x AS INTEGER, y AS INTEGER, pptl AS POINT PTR)
  pptl->x = BRD_HORZMARGIN + y *(BRD_HORZFRONT - BRD_HORZBACK) / 2 + x *(y *BRD_HORZBACK + (8 - y) *BRD_HORZFRONT) / 8
  pptl->y = (BRD_BACKMARGIN + 8 *BRD_VERT + BRD_FRONTMARGIN) - y *BRD_VERT
END SUB

SUB QuerySqCoords (x AS INTEGER, y AS INTEGER, aptl[] AS POINT)
  QuerySqOrigin (x, y, aptl + 0)
  QuerySqOrigin (x + 1, y, aptl + 1)
  QuerySqOrigin (x + 1, y + 1, aptl + 2)
  QuerySqOrigin (x, y + 1, aptl + 3)
END SUB

SUB DrawOneSquare (hDC AS HDC, x AS INTEGER, y AS INTEGER)
  DIM RAW aptl[4] AS POINT

  QuerySqCoords (x, y, aptl)
  Polygon (hDC, aptl, 4)
END SUB

'
'Draw the board.  Pass the routine the upper left connor and the
'colors to draw the squares.
'

SUB Draw_Board (hDC AS HDC, reverse AS INTEGER, DarkColor AS DWORD, LightColor AS DWORD)
  DIM RAW x AS INTEGER, y AS INTEGER, OldPolyMode AS INTEGER
  DIM RAW hOldBrush AS HBRUSH, hBrush_lt AS HBRUSH, hBrush_dk AS HBRUSH
  DIM RAW hOldPen AS HPEN
  DIM RAW aptl[4] AS POINT

  hBrush_lt = CreateSolidBrush (LightColor)
  hBrush_dk = CreateSolidBrush (DarkColor)

  hOldBrush = SelectObject (hDC, hBrush_lt)
  hOldPen = SelectObject (hDC, GetStockObject (BLACK_PEN))


  OldPolyMode = SetPolyFillMode (hDC, WINDING)

  y = 0
  WHILE y<8
    x = 0
    WHILE x<8
      IF reverse = 0 THEN
        ! SelectObject ( hDC, ((x+y ) &1 ) ? hBrush_lt : hBrush_dk ) ;
        DrawOneSquare (hDC, x, y)
      ELSE
        ! SelectObject ( hDC , ( ( ( 7 - x ) + ( 7 - y ) ) & 1 ) ? hBrush_lt : hBrush_dk ) ;
        DrawOneSquare (hDC, 7 - x, 7 - y)
      END IF
      x++
    WEND
    y++
  WEND

  ' Now draw the bottom edge of the board

  x = 0
  WHILE x<8
    QuerySqCoords (x, 0, aptl)

    aptl[2] .x = aptl[1] .x
    aptl[2] .y = aptl[1] .y + BRD_EDGE

    aptl[3] .x = aptl[0] .x
    aptl[3] .y = aptl[0] .y + BRD_EDGE

    ! SelectObject ( hDC, (x&1 ) ? hBrush_lt : hBrush_dk ) ;
    Polygon (hDC, aptl, 4)
    x++
  WEND
  SetPolyFillMode (hDC, OldPolyMode)

  SelectObject (hDC, hOldPen)
  SelectObject (hDC, hOldBrush)

  DeleteObject (hBrush_lt)
  DeleteObject (hBrush_dk)
END SUB

SUB DrawCoords (hDC AS HDC, reverse AS INTEGER, clrBackGround AS DWORD, clrText AS DWORD)
  DIM RAW hFont AS HFONT, hOldFont AS HFONT
  DIM RAW i AS INTEGER, OldBkMode AS INTEGER
  DIM RAW OldBkColor AS DWORD, OldTextColor AS DWORD
  DIM RAW xchar AS INTEGER, ychar AS INTEGER
  DIM RAW pt AS POINT
  DIM RAW tm AS TEXTMETRIC

  hFont = CreateFont (13, 0, 0, 0, FW_NORMAL, FALSE, FALSE, FALSE, ANSI_CHARSET, OUT_DEFAULT_PRECIS, CLIP_DEFAULT_PRECIS, DEFAULT_QUALITY, FIXED_PITCH BOR FF_SWISS, "Helv")

  hOldFont = SelectObject (hDC, hFont)
  OldBkColor = SetBkColor (hDC, clrBackGround)
  OldBkMode = SetBkMode (hDC, TRANSPARENT)
  OldTextColor = SetTextColor (hDC, clrText)

  GetTextMetrics (hDC, &tm)
  xchar = tm.tmMaxCharWidth
  ychar = tm.tmHeight

  i = 0
  WHILE i<8
    QuerySqOrigin (0, i, &pt)
    ! TextOut (hDC, pt.x-xchar, pt.y-BRD_VERT/2-ychar/2, (reverse ? "87654321"+i : "12345678"+i ),1);
    QuerySqOrigin (i, 0, &pt)
    ! TextOut (hDC, pt.x+BRD_HORZFRONT/2-xchar/2, pt.y+BRD_EDGE, (reverse ? "hgfedcba"+i : "abcdefgh"+i ), 1);
    i++
  WEND

  SelectObject (hDC, hOldFont)
  DeleteObject (hFont)

  SetBkColor (hDC, OldBkColor)
  SetBkMode (hDC, OldBkMode)
  SetTextColor (hDC, OldTextColor)
END SUB


SUB DrawWindowBackGround (hDC AS HDC, hWnd AS HWND, bkcolor AS DWORD)
  DIM RAW rect AS RECT
  DIM RAW hBrush AS HBRUSH, hOldBrush AS HBRUSH

  hBrush = CreateSolidBrush (bkcolor)
  hOldBrush = SelectObject (hDC, hBrush)
  GetClientRect (hWnd, &rect)
  FillRect (hDC, &rect, hBrush)
  SelectObject (hDC, hOldBrush)
  DeleteObject (hBrush)
END SUB

SUB HiliteSquare (hWnd AS HWND, Square AS INTEGER)
  DIM RAW hDC AS HDC
  DIM RAW x AS INTEGER, y AS INTEGER
  DIM RAW aptl[4] AS POINT
  DIM RAW hRgn AS HRGN

  y = Square / 8
  x = Square % 8

  QuerySqCoords (x, y, aptl + 0)
  hRgn = CreatePolygonRgn (aptl, 4, WINDING)

  hDC = GetDC (hWnd)
  InvertRgn (hDC, hRgn)
  ReleaseDC (hWnd, hDC)

  DeleteObject (hRgn)
  HilitSq = Square
END SUB

SUB UnHiliteSquare (hWnd AS HWND, Square AS INTEGER)
  DIM RAW hDC AS HDC
  DIM RAW x AS INTEGER, y AS INTEGER
  DIM RAW aptl[4] AS POINT
  DIM RAW hRgn AS HRGN

  IF HilitSq = - 1 THEN
    EXIT SUB
  END IF
  y = Square / 8
  x = Square % 8

  QuerySqCoords (x, y, aptl + 0)
  hRgn = CreatePolygonRgn (aptl, 4, WINDING)

  hDC = GetDC (hWnd)
  InvertRgn (hDC, hRgn)
  ReleaseDC (hWnd, hDC)

  DeleteObject (hRgn)

  HilitSq = - 1
END SUB

